@@ -143,6 +143,18 @@ sub _apply_to_number {
     return $value;
 }
 
+sub _extract_numeric_values {
+    my ($values) = @_;
+
+    return () unless ref $values eq 'ARRAY';
+
+    return map {
+        JSON::PP::is_bool($_) ? ($_ ? 1 : 0) : 0 + $_;
+    } grep {
+        defined $_ && (JSON::PP::is_bool($_) || (!ref $_ && looks_like_number($_)));
+    } @$values;
+}
+
 sub _normalize_percentile {
     my ($value) = @_;
 
@@ -1418,7 +1430,9 @@ sub _apply_uri {
         $text = "$value";
     }
 
-    my $encoded = encode('UTF-8', $text);
+    my $encoded = is_utf8($text, 1)
+        ? encode('UTF-8', $text)
+        : $text;
     $encoded =~ s/([^A-Za-z0-9\-._~])/sprintf('%%%02X', ord($1))/ge;
     return $encoded;
 }
